==> nextcloud-14.0.13.zip: nextcloud/apps/activity/l10n/ia.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activitate",
    "An error occurred while loading activities" : "Un error durante le cargamento de activitates",
    "No activity yet" : "Nulle activitate ancora",
    "Load more activities" : "Incarga altere activitates",
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "{name} (invisible)" : "{name} (invisibile)",
    "{name} (restricted)" : "{name} (restringite)",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Iste fluxo monstra eventos como additiones, cambiamentos e compartimentos",
    "There are no events for this filter" : "Il non ha eventos pro iste filtro",
    "Today" : "Hodie",
    "Yesterday" : "Heri",
    "Personal activity feed for %s" : "Syndication de activitate personal pro %s",
    "Your feed URL is invalid" : "Le URL del syndication es invalide",
    "Your settings have been updated." : "Tu configurationes ha essite actualisate.",
    "Settings have been updated." : "Configurationes actualisate",
    "All activities" : "Omne activitates",
    "By others" : "Per alteres",
    "By you" : "Per vos",
    "Hello %s," : "Salute %s,",
    "There was some activity at %s" : "Il habeva alcun activitate in %s",
    "Mail" : "Posta",
    "Stream" : "Fluxo",
    "Activity feed" : "Syndication de activitate",
    "List your own actions in the stream" : "Lista tu proprie actiones de file in le fluxo",
    "Notify about your own actions via email" : "Notifica super tu proprie actiones via e-posta",
    "You need to set up your email address before you can receive notification emails." : "Tu necessita configurar tu adresse de e-posta ante que tu pote reciper messages de e-posta de notification.",
    "Send emails:" : "Invia messages de e-posta:",
    "Hourly" : "Cata hora",
    "Daily" : "Cata die",
    "Weekly" : "Cata septimana",
    "Settings" : "Configurationes",
    "Enable RSS feed" : "Habilita syndication RSS",
    "No more events to load" : "Nulle altere eventos a cargar",
    "Activities" : "Activitates",
    "\"remote user\"" : "\"usator remote\"",
    ", " : ",",
    "%s and %s" : "%s e %s",
    "Files" : "Files"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.6.zip: nextcloud/apps/activity/l10n/ia.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activitate",
    "An error occurred while loading activities" : "Un error durante le cargamento de activitates",
    "No activity yet" : "Nulle activitate ancora",
    "Load more activities" : "Incarga altere activitates",
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "{name} (invisible)" : "{name} (invisibile)",
    "{name} (restricted)" : "{name} (restringite)",
    "Home" : "Initio",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Iste fluxo monstra eventos como additiones, cambiamentos e compartimentos",
    "There are no events for this filter" : "Il non ha eventos pro iste filtro",
    "Today" : "Hodie",
    "Yesterday" : "Heri",
    "Open file" : "Aperir file",
    "Personal activity feed for %s" : "Syndication de activitate personal pro %s",
    "Your feed URL is invalid" : "Le URL del syndication es invalide",
    "Your settings have been updated." : "Tu configurationes ha essite actualisate.",
    "Settings have been updated." : "Configurationes actualisate",
    "All activities" : "Omne activitates",
    "By others" : "Per alteres",
    "By you" : "Per vos",
    "Hello %s," : "Salute %s,",
    "There was some activity at %s" : "Il habeva alcun activitate in %s",
    "Mail" : "Posta",
    "Stream" : "Fluxo",
    "Activity feed" : "Syndication de activitate",
    "Default settings" : "Configurationes predefinite",
    "List your own actions in the stream" : "Lista tu proprie actiones de file in le fluxo",
    "Notify about your own actions via email" : "Notifica super tu proprie actiones via e-posta",
    "You need to set up your email address before you can receive notification emails." : "Tu necessita configurar tu adresse de e-posta ante que tu pote reciper messages de e-posta de notification.",
    "Send emails:" : "Invia messages de e-posta:",
    "Hourly" : "Cata hora",
    "Daily" : "Cata die",
    "Weekly" : "Cata septimana",
    "Settings" : "Configurationes",
    "Enable RSS feed" : "Habilita syndication RSS",
    "No more events to load" : "Nulle altere eventos a cargar",
    "\"remote user\"" : "\"usator remote\"",
    ", " : ",",
    "%s and %s" : "%s e %s",
    "Files" : "Files"
},
"nplurals=2; plural=(n != 1);");
